@@ -300,7 +300,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_2)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText ("Health Check V 0.4.1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com")
+        self.textBrowser.setText ("Health Check V 0.4.2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -457,7 +457,7 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText(".......")
         self.updateBatt()
         self.pushButton_hw.setText("........")
-        self.Cellular()
+        #self.Cellular()
         self.pushButton_hw.setText("Update")
         self.pushButton_hw.setEnabled(True)
 
